@@ -140,7 +140,7 @@ gboolean gok_settingsdialog_open (gboolean bShow)
                       GTK_SIGNAL_FUNC (on_button_help),
                       NULL);
 	
-	gtk_button_set_label (GTK_BUTTON(pButtonTry), "_Try");
+	gtk_button_set_label (GTK_BUTTON(pButtonTry), _("_Try"));
 /*	gtk_button_set_use_stock (GTK_BUTTON(pButtonTry), TRUE); */
 
 	gtk_widget_ref (pButtonTry);
@@ -280,16 +280,17 @@ GtkWidget* gok_settingsdialog_get_window ()
 **/
 void gok_settingsdialog_close()
 {
+	gok_log_enter();
 	if (m_pWindowSettings != NULL)
 	{
-		gtk_widget_destroy (m_pWindowSettings);
-	
 		gok_page_accessmethod_close();
+		gtk_widget_destroy (m_pWindowSettings);
 	}
 	else
 	{
 		g_warning("The settings dialog doesn't exist in close function!");
 	}
+	gok_log_leave();
 }
 
 /**
